summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/objectnamelist.h
diff options
context:
space:
mode:
Diffstat (limited to 'kstars/kstars/objectnamelist.h')
-rw-r--r--kstars/kstars/objectnamelist.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kstars/kstars/objectnamelist.h b/kstars/kstars/objectnamelist.h
index ea19f621..63f5349a 100644
--- a/kstars/kstars/objectnamelist.h
+++ b/kstars/kstars/objectnamelist.h
@@ -87,7 +87,7 @@ class ObjectNameList {
*@param name name of object to find.
*@return pointer to object with the given name
*/
- SkyObjectName* tqfind(const TQString &name = TQString());
+ SkyObjectName* find(const TQString &name = TQString());
/**@short remove the named object from the list.
*@param name the name of the object to be removed.
@@ -118,7 +118,7 @@ class ObjectNameList {
private:
/**Sorts the lists with objects for faster access.
*It's needed for tqfind(). first() and tqfind() call this function.
*/
void sort();
@@ -118,7 +118,7 @@ class ObjectNameList {
private:
/**Sorts the lists with objects for faster access.
- *It's needed for tqfind(). first() and tqfind() call this function.
+ *It's needed for find(). first() and find() call this function.
*/
void sort();